/*
 * Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
 *
 * This file is part of NRAO Workspaces.
 *
 * Workspaces is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Workspaces is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
 */
import { Pipe, PipeTransform } from '@angular/core';

@Pipe({
  name: 'fileSize'
})
export class FileSizePipe implements PipeTransform {

  transform(value: any, args?: any): any {
    if (isNaN(value) || value == 0) return '0 Bytes';

    const sizes: Array<string> = ['B', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB'];
    const k: number = 1024;
    const filledDot: string = '●';
    const emptyDot: string = '○';
    const i = Math.floor(Math.log(value) / Math.log(k));

    if(args && args == 'withDots') {
      return parseFloat((value / Math.pow(k, i)).toFixed(1)) + ' ' + sizes[i] + ' ' + filledDot.repeat(i) + emptyDot.repeat(4 - i);
    } else {
      return parseFloat((value / Math.pow(k, i)).toFixed(1)) + ' ' + sizes[i];

    }
  }

}
